@@ -13,17 +13,17 @@ try:
 except Exception:
     from pymavlink.generator import mavparse
 
-try:
-    from lib.genxmlif import GenXmlIfError
-    from lib.minixsv import pyxsval
-    performValidation = True
-except Exception:
-    print("Unable to load XML validator libraries. XML validation will not be performed")
-    performValidation = False
-    
 # XSD schema file
 schemaFile = os.path.join(os.path.dirname(os.path.realpath(__file__)), "mavschema.xsd")
 
+# Set defaults for generating MAVLink code
+DEFAULT_WIRE_PROTOCOL = mavparse.PROTOCOL_1_0
+DEFAULT_LANGUAGE = 'Python'
+DEFAULT_ERROR_LIMIT = 200
+DEFAULT_VALIDATE = True
+
+# List the supported languages. This is done globally because it's used by the GUI wrapper too
+supportedLanguages = ["C", "CS", "JavaScript", "Python", "WLua"]
 
 def mavgen(opts, args) :
     """Generate mavlink message formatters and parsers (C and Python ) using options
@@ -33,8 +33,24 @@ def mavgen(opts, args) :
 
     xml = []
 
+    # Enable validation by default, disabling it if explicitly requested
+    if opts.validate:
+        try:
+            from lib.genxmlif import GenXmlIfError
+            from lib.minixsv import pyxsval
+        except Exception:
+            print("WARNING: Unable to load XML validator libraries. XML validation will not be performed")
+            opts.validate = False
+
+    def mavgen_validate(fname, schema, errorLimitNumber) :
+        """Uses minixsv to validate an XML file with a given XSD schema file. We define mavgen_validate
+           here because it relies on the XML libs that were loaded in mavgen(), so it can't be called standalone"""
+        # use default values of minixsv, location of the schema file must be specified in the XML file
+        domTreeWrapper = pyxsval.parseAndValidate(fname, xsdFile=schema, errorLimit=errorLimitNumber)
+
+    # Process all XML files, validating them as necessary.
     for fname in args:
-        if performValidation:
+        if opts.validate:
             print("Validating %s" % fname)
             mavgen_validate(fname, schemaFile, opts.error_limit);
         else:
@@ -49,7 +65,7 @@ def mavgen(opts, args) :
             fname = os.path.join(os.path.dirname(x.filename), i)
 
             ## Validate XML file with XSD file if possible.
-            if performValidation:
+            if opts.validate:
                 print("Validating %s" % fname)
                 mavgen_validate(fname, schemaFile, opts.error_limit);
             else:
@@ -121,11 +137,12 @@ def mavgen(opts, args) :
 
 # build all the dialects in the dialects subpackage
 class Opts:
-    def __init__(self, wire_protocol, output):
+    def __init__(self, output, wire_protocol=DEFAULT_WIRE_PROTOCOL, language=DEFAULT_LANGUAGE, validate=DEFAULT_VALIDATE, error_limit=DEFAULT_ERROR_LIMIT):
         self.wire_protocol = wire_protocol
-        self.error_limit = 200
-        self.language = 'Python'
+        self.error_limit = error_limit
+        self.language = language
         self.output = output
+        self.validate = validate
 
 def mavgen_python_dialect(dialect, wire_protocol):
     '''generate the python code on the fly for a MAVLink dialect'''
@@ -141,7 +158,7 @@ def mavgen_python_dialect(dialect, wire_protocol):
         xml = os.path.join(dialects, 'v10', dialect + '.xml')
         if not os.path.exists(xml):
             xml = os.path.join(mdef, 'v1.0', dialect + '.xml')
-    opts = Opts(wire_protocol, py)
+    opts = Opts(py, wire_protocol)
     import StringIO
 
     # throw away stdout while generating
@@ -154,26 +171,17 @@ def mavgen_python_dialect(dialect, wire_protocol):
         sys.stdout = stdout_saved
         raise
     sys.stdout = stdout_saved
-    
-
-def mavgen_validate(fname, schema, errorLimitNumber) :
-    """Uses minixsv to validate an XML file with a given XSD schema file."""
-    # use default values of minixsv, location of the schema file must be specified in the XML file
-    domTreeWrapper = pyxsval.parseAndValidate(fname, xsdFile=schema, errorLimit=errorLimitNumber)
-            
-    # domTree is a minidom document object
-    domTree = domTreeWrapper.getTree()
 
 
 if __name__ == "__main__":
     from optparse import OptionParser
 
-    supportedLanguages = ["C", "CS", "JavaScript", "Python", "WLua", "ObjC"]
     parser = OptionParser("%prog [options] <XML files>")
     parser.add_option("-o", "--output", dest="output", default="mavlink", help="output directory.")
-    parser.add_option("--lang", dest="language", choices=supportedLanguages, default="Python", help="language of generated code, one of: {0} [default: %default]".format(supportedLanguages))
-    parser.add_option("--wire-protocol", dest="wire_protocol", choices=[mavparse.PROTOCOL_0_9, mavparse.PROTOCOL_1_0], default=mavparse.PROTOCOL_1_0, help="MAVLink protocol version: '0.9' or '1.0'. [default: %default]")
-    parser.add_option("--error-limit", dest="error_limit", default=200, help="maximum number of validation errors.")
+    parser.add_option("--lang", dest="language", choices=supportedLanguages, default=DEFAULT_LANGUAGE, help="language of generated code, one of: {0} [default: %default]".format(supportedLanguages))
+    parser.add_option("--wire-protocol", dest="wire_protocol", choices=[mavparse.PROTOCOL_0_9, mavparse.PROTOCOL_1_0], default=DEFAULT_WIRE_PROTOCOL, help="MAVLink protocol version: '0.9' or '1.0'. [default: %default]")
+    parser.add_option("--no-validate", action="store_false", dest="validate", default=DEFAULT_VALIDATE, help="Do not perform XML validation. Can speed up code generation if XML files are known to be correct.")
+    parser.add_option("--error-limit", dest="error_limit", default=DEFAULT_ERROR_LIMIT, help="maximum number of validation errors to display")
     (opts, args) = parser.parse_args()
 
     if len(args) < 1:
